// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:http/http.dart';
import 'package:wyatt_http_client/src/utils/http_status.dart';

/// {@template middleware_response}
/// A class that represents a middleware response.
/// {@endtemplate}
class MiddlewareResponse {
  /// {@macro middleware_response}
  const MiddlewareResponse({
    required this.httpResponse,
  });

  /// {@macro middleware_response}
  final BaseResponse httpResponse;

  /// The status code of the response. (proxy)
  int get statusCode => httpResponse.statusCode;

  /// The status of the response. (proxy)
  HttpStatus get status => HttpStatus.from(statusCode);

  /// The body of the response. (proxy or empty string)
  String get body {
    if (httpResponse is Response) {
      return (httpResponse as Response).body;
    } else {
      return '';
    }
  }

  /// The content length of the response. (proxy)
  int? get contentLength => httpResponse.contentLength;

  /// The headers of the response. (proxy)
  Map<String, String> get headers => httpResponse.headers;

  /// Returns a copy of this response with the given [httpResponse].
  MiddlewareResponse copyWith({
    BaseResponse? httpResponse,
  }) =>
      MiddlewareResponse(
        httpResponse: httpResponse ?? this.httpResponse,
      );

  @override
  String toString() => 'MiddlewareResponse(httpResponse: $httpResponse)';
}
